Installation
============

Requirements
------------

**pythonbible** requires Python version 3.7 or greater.

.. note::

   **pythonbible** should work with Python 3.6 if dataclasses is installed, but it is not officially supported.

**pythonbible** has no other dependencies.

How to Install
--------------

To use **pythonbible**, first install it using pip:

.. code-block:: console

    $ python3 -m pip install pythonbible